import bpy

from .. import utils
from .. import constants

class THOMAS_RIG_UPDATE_RIG(bpy.types.Operator):
    bl_idname = "thomasriglegacy.update_rig"
    bl_label = "update"
    bl_options = {'REGISTER', 'UNDO'}

    rig = None
    rig_version = None
    ext_version = None
    
    @classmethod
    def poll(cls, context):
        rig = utils.get_rig()

        if not rig or not rig.get("Rig_ID") == constants.RIG_ID:
            return False
        
        rig_version = rig.get("rig_version", "unknown")
        return rig_version == "unknown" or tuple(rig_version) < utils.get_ext_version()
    
    @classmethod
    def manual_update_poll(cls, rig: bpy.types.Object) -> bool | list[str]:
        rig_version = rig.get("rig_version", "unknown")

        if rig_version != "unknown" and tuple(rig_version) >= (1, 1, 0):
            return False
        
        return ("manual upate required.", "can result in unexpected errors.")

    def execute(self, context):
        self.rig = utils.get_rig()
        self.rig_version = self.rig.get("rig_version", None)
        self.ext_version = utils.get_ext_version()

        # set rig version to newest
        self.rig["rig_version"] = self.ext_version
        self.rig.data.update_tag()
        bpy.context.view_layer.update()
        self.report({"INFO"}, "Rig updated to v" + '.'.join(map(str, self.ext_version)))
        return {'FINISHED'}